==> tkScenarist-1.1.3.tar.gz: tkScenarist-1.1.3/tkScenarist/html/fr/md/fr_readme.md <==

# tkScenarist

Screen writing made simpler &ndash; Simplifiez-vous la vie !

## <a name="presentation"/>Présentation

`tkScenarist` est une petite application écrite en Python3/Tkinter qui
vise à faciliter la rédaction de scénarios de films pour tous les
scénaristes en herbe, futurs et à venir.

Ce logiciel est un **freefullware** (voir [ci-dessous](#freefullware)).


## <a name="copyright"/>Copyright

tkScenarist - screen writing made simpler.

Copyright (c) 2014+ Raphaël Seban <motus@laposte.net>


## <a name="licence"/>Licence

Ce logiciel est publié sous licence **GNU GPL General Public License
v3**.

Les termes de cette licence doivent rester intacts, c'est-à-dire -
entre autres - qu'ils ne doivent pas être traduits.

Termes de la licence (en anglais) :

> This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

> This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

> You should have received a copy of the GNU General Public License
along with this program.

> If not, see <http://www.gnu.org/licenses/>


## <a name="freefullware"/>Freefullware

Qu'est-ce qu'un freefullware?

Un logiciel est dit **freefullware** lorsque :

* **il est libre** d'utilisation, de modification et de partage ;
* il est **totalement gratuit** ;
* il ne contient absolument **aucune publicité** ;
* **il n'a pas** de bouton 'Donate' (donner pour aider) ;
* il est **garanti 100% virus-free** (sans virus connu) ;
* il n'attend **aucune contrepartie** de votre part ;
* il est vraiment **absolument libre**, dans tous les sens du terme ;

Téléchargez-le, utilisez-le et amusez-vous bien.

That's all, folks!


## <a name="fonctionnalites"/>Fonctionnalités

À cette heure :

* toute la gestion du projet a été concentrée en un seul fichier projet
unique, qui porte l'extension de fichier `.scn` ou `.zip` (au choix,
c'est comme vous voulez)&nbsp;;

* en cas d'urgence, il vous est toujours possible de dézipper ce
fichier projet unique pour récupérer les différents éléments du projet,
tous stockés sous la forme de **fichiers texte brut encodés UTF-8**.
Cette procédure a été voulue ainsi afin que vous puissiez toujours
rester maître de vos données&nbsp;;

* le premier onglet de l'application représente le `titre` de votre
projet, ainsi que diverses informations telles que&nbsp;: titre,
sous-titre, épisode, auteur, e-mail auteur, tél. auteur et quelques
stats sur le projet lui-même&nbsp;;

* le second onglet permet de gérer des `notes personnelles` concernant
votre projet de film&nbsp;;

* le troisième onglet permet d'écrire le `pitch` ou le concept de
l'histoire (rappelons ici vite fait que le pitch est un résumé très
succinct de l'histoire), bref, d'y recenser tous les moments forts du
film à venir&nbsp;;

* au cas où vous auriez besoin d'un petit coup de pouce pour votre
inspiration, un outil est disponible dans le menu `Outils > Modèles
d'histoires/pitchs`&nbsp;: il vous offre une série extensible de
modèles d'histoire à prendre comme point de départ pour vos propres
idées&nbsp;;

* le quatrième onglet de l'application, `Personnages`, est un outil
fort pratique&nbsp;: vous pouvez y déclarer tous les protagonistes de
votre histoire, renseigner leur histoire personnelle et même gérer
visuellement les relations qui les lient entre eux&nbsp;;

* au cas où vous auriez besoin d'un petit coup de pouce pour votre
inspiration, un outil est disponible dans le menu `Outils > BDD noms de
personnages`&nbsp;: une base de données (BDD) de centaines de noms de
personnages provenant de toute la planète est à votre disposition pour
apporter un plus à votre projet&nbsp;;

* le cinquième onglet `Scénario` est sans doute le plus important pour
un(e) scénariste&nbsp;: c'est ici que s'écrit l'histoire, le scénario,
conformément aux règles du métier. Merci de consulter la doc wiki pour
plus d'information sur son utilisation détaillée&nbsp;;

* un petit outil supplémentaire est désormais disponible dans le menu
`Outils > Éléments de scénario` qui vous permet de régler plus finement
l'utilisation de l'éditeur de scénario qui se trouve dans le cinquième
onglet de l'application&nbsp;;

* le sixième onglet, `Storyboard`, permet de gérer le **découpage
technique** du scénario. Cet outil vous est offert en extra.
Normalement, le logiciel `tkScenarist` aurait dû s'arrêter à la
rédaction du scénario, mais pour les petits projets de film, je me suis
dit que ce serait bien pratique d'avoir aussi le storyboard à portée de
main&nbsp;;

* idem pour le septième onglet, `Ressources`, qui n'est là que pour
faciliter l'organisation des petits projets de film. Il va sans dire
qu'un projet de film plus ambitieux nécessitera sans aucun doute des
logiciels plus puissants (et moins gratuits, au passage)&nbsp;;

* l'outil d'exportation des données du projet vers le format PDF
imprimable autorise à présent la gestion de documents multiples,
séparés les uns des autres, avec des options à régler juste avant le
lancement de la procédure d'exportation&nbsp;;

* le logiciel `tkScenarist` est à présent entièrement traduit en
**français de France métropolitaine** (fr_FR).


## <a name="captures-d-ecran"/>Captures d'écran

![image](../../images/screenshots/fr/screenshot-001.png)
![image](../../images/screenshots/fr/screenshot-002.png)
![image](../../images/screenshots/fr/screenshot-003.png)
![image](../../images/screenshots/fr/screenshot-004.png)
![image](../../images/screenshots/fr/screenshot-005.png)
![image](../../images/screenshots/fr/screenshot-006.png)
![image](../../images/screenshots/fr/screenshot-007.png)
![image](../../images/screenshots/fr/screenshot-008.png)
![image](../../images/screenshots/fr/screenshot-009.png)
![image](../../images/screenshots/fr/screenshot-010.png)
![image](../../images/screenshots/fr/screenshot-011.png)
![image](../../images/screenshots/fr/screenshot-012.png)
![image](../../images/screenshots/fr/screenshot-013.png)

![image](../../images/screenshots/fr/screenshot-014.png)
![image](../../images/screenshots/fr/screenshot-015.png)
![image](../../images/screenshots/fr/screenshot-016.png)


## <a name="avancement-du-projet"/>Avancement du projet

    Development Status :: 5 - Production/Stable

Ce logiciel a été :

* Linux:
    * TESTÉ OK pour toutes les distributions standards ;
* MacOS:
    * PAS ENCORE TESTÉ ;
* MS-Windows:
    * TESTÉ seulement avec MS-Windows(tm) 8, mais semble fonctionner
    plutôt bien, pour le moment ;

Tout retour d'expérience dans le
**[bugtracker](https://github.com/tarball69/tkScenarist/issues)** du
projet est toujours le bienvenu.


## <a name="installation"/>Installation

Ce logiciel n'a *PAS* besoin d'être installé, de quelque manière que ce
soit.

Il vous suffit de le télécharger à la page
[Releases](https://github.com/tarball69/tkScenarist/releases) du projet
GitHub, de dézipper l'archive téléchargée et de l'utiliser
immédiatement.

Bien sûr, dans l'idéal, vous prendrez la précaution de copier le
dossier obtenu dans l'un de vos dossiers préférés &ndash; exemple
`apps` &ndash; sachant qu'un logiciel qui traîne dans le dossier des
téléchargements a toutes les chances de se faire supprimer
accidentellement.


## <a name="demarrage-rapide"/>Démarrage rapide

### <a name="important"/>Important

Ce logiciel ne peut fonctionner que si **Python3** (v >= 3.3) et
**Tkinter** sont correctement installés sur votre machine.

En revanche, il n'y a **pas d'autres dépendances** que ces deux
pré-requis.

Python3 est le langage de programmation utilisé par le logiciel
`tkScenarist` et Tkinter sa bibliothèque graphique, généralement
installée **par défaut** avec le langage Python3.

Si jamais vous obtenez un message d'erreur du type **ImportError** dans
la fenêtre noire (console) qui apparaît lors du lancement du logiciel,
c'est qu'il y a de fortes chances pour que vous essayiez de lancer le
programme avec **Python2** et non pas son grand frère **Python3**. Il
peut arriver parfois aussi que la bibliothèque Tkinter soit mal
installée, bien que ce soit rare.

Quoi qu'il en soit, n'hésitez pas à vous faire aider sur les forums
d'entraide appropriés (par exemple :
[AFPY.org](http://www.afpy.org/forums/forum_python)).

Notez que l'installation de Python3 à côté de Python2 ne pose
généralement aucun problème particulier.

Vous pouvez télécharger et installer Python3 à partir de cette
adresse&nbsp;:

<https://www.python.org/downloads/> (Ctrl+clic: nouvel onglet)

### <a name="note"/>Note

La plupart des distributions Linux populaires e.g. Ubuntu, Debian,
SuSE, etc. ont déjà une **pré-installation** de Python3/Tkinter.

Si vous êtes dans ce cas, **n'essayez pas** d'installer Python3/Tkinter
manuellement, non seulement c'est totalement inutile, mais de plus,
cela pourrait mettre une sacrée grouille dans votre système.

Dans un tel cas, il vous suffit de [télécharger une release](https://github.com/tarball69/tkScenarist/releases) de `tkScenarist`,
de la dézipper et de l'utiliser immédiatement.

### <a name="usagers-de-ms-windows"/>Usagers de MS-Windows&trade;

Une fois le dossier `tkScenarist-...` dézippé et copié en lieu sûr,
double-cliquez simplement sur le fichier `tkscenarist.py` qui se trouve
dedans pour lancer l'application.

#### <a name="vous-ne-voulez-pas-la-console-noire"/>Vous ne voulez pas la console noire

Plusieurs usagers de MS-Windows&trade; ont fait remarquer qu'ils ont
une console MS-DOS noire qui apparaît au lancement du logiciel.

Cette fenêtre particulièrement disgracieuse peut même parfois être
carrément gênante.

Il s'agit cependant d'un comportement propre au langage Python sous
MS-Windows&trade; et **cela n'a rien d'anormal**.

Toutefois, si vous souhaitez vous débarrasser de cette console noire,
il vous suffit de changer l'extension du fichier `.py` en `.pyw` puis
de lancer à nouveau votre logiciel favori pour ne plus être embêté(e).

Dans le cas ici présent, cela revient à renommer le fichier
`tkscenarist.py` en `tkscenarist.pyw`, puis de relancer le programme
pour que cela fonctionne sans console.

### <a name="unixlinux"/>UNIX/Linux

Une fois le dossier `tkScenarist-...` dézippé et copié en lieu sûr,
cliquez simplement sur le fichier `tkscenarist.py` qui se trouve dedans
(si le sticky bit 'executable' autorise l'exécution du fichier tel
quel) pour lancer l'application.

Si cela ne donne rien, ouvrez une console shell et tapez :

<pre class="codeblock">
    $ cd /emplacement/du/fichier # à remplacer, évidemment.
    $ python3 tkscenarist.py
</pre>

**Exemple concret&nbsp;:** en supposant que vous avez copié le dossier
`tkScenarist/` dans votre répertoire favori `~/apps/`, cela
donne&nbsp;:

<pre class="codeblock">
    $ cd ~/apps/tkScenarist
    $ python3 tkscenarist.py
</pre>

That's all, folks!

Amusez-vous bien !

==> tkScenarist-1.3.2.tar.gz: tkScenarist-1.3.2/tkScenarist/html/fr/md/fr_readme.md <==

# tkScenarist

Screen writing made simpler &ndash; Simplifiez-vous la vie !

## <a name="presentation"/>Présentation

`tkScenarist` est une petite application écrite en Python3/Tkinter qui
vise à faciliter la rédaction de scénarios de films pour tous les
scénaristes en herbe, futurs et à venir.

Ce logiciel est un **freefullware** (voir [ci-dessous](#freefullware)).


## <a name="copyright"/>Copyright

tkScenarist - screen writing made simpler.

Copyright (c) 2014+ Raphaël Seban <motus@laposte.net>


## <a name="licence"/>Licence

Ce logiciel est publié sous licence **GNU GPL General Public License
v3**.

Les termes de cette licence doivent rester intacts, c'est-à-dire -
entre autres - qu'ils ne doivent pas être traduits.

Termes de la licence (en anglais) :

> This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

> This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

> You should have received a copy of the GNU General Public License
along with this program.

> If not, see <http://www.gnu.org/licenses/>


## <a name="freefullware"/>Freefullware

Qu'est-ce qu'un freefullware?

Un logiciel est dit **freefullware** lorsque :

* **il est libre** d'utilisation, de modification et de partage ;
* il est **totalement gratuit** ;
* il ne contient absolument **aucune publicité** ;
* **il n'a pas** de bouton 'Donate' (donner pour aider) ;
* il est **garanti 100% virus-free** (sans virus connu) ;
* il n'attend **aucune contrepartie** de votre part ;
* il est vraiment **absolument libre**, dans tous les sens du terme.

Téléchargez-le, utilisez-le et amusez-vous bien.

That's all, folks!


## <a name="fonctionnalites"/>Fonctionnalités

À cette heure :

* toute la gestion du projet a été concentrée en un seul fichier projet
unique, qui porte l'extension de fichier `.scn` ou `.zip` (au choix,
c'est comme vous voulez)&nbsp;;

* en cas d'urgence, il vous est toujours possible de dézipper ce
fichier projet unique pour récupérer les différents éléments du projet,
tous stockés sous la forme de **fichiers texte brut encodés UTF-8**.
Cette procédure a été voulue ainsi afin que vous puissiez toujours
rester maître de vos données&nbsp;;

* le premier onglet de l'application représente le `titre` de votre
projet, ainsi que diverses informations telles que&nbsp;: titre,
sous-titre, épisode, auteur, e-mail auteur, tél. auteur et quelques
stats sur le projet lui-même&nbsp;;

* le second onglet permet de gérer des `notes personnelles` concernant
votre projet de film&nbsp;;

* le troisième onglet permet d'écrire le `pitch` ou le concept de
l'histoire (rappelons ici vite fait que le pitch est un résumé très
succinct de l'histoire), bref, d'y recenser tous les moments forts du
film à venir&nbsp;;

* au cas où vous auriez besoin d'un petit coup de pouce pour votre
inspiration, un outil est disponible dans le menu `Outils > Modèles
d'histoires/pitchs`&nbsp;: il vous offre une série extensible de
modèles d'histoire à prendre comme point de départ pour vos propres
idées&nbsp;;

* le quatrième onglet de l'application, `Personnages`, est un outil
fort pratique&nbsp;: vous pouvez y déclarer tous les protagonistes de
votre histoire, renseigner leur histoire personnelle et même gérer
visuellement les relations qui les lient entre eux&nbsp;;

* au cas où vous auriez besoin d'un petit coup de pouce pour votre
inspiration, un outil est disponible dans le menu `Outils > BDD noms de
personnages`&nbsp;: une base de données (BDD) de centaines de noms de
personnages provenant de toute la planète est à votre disposition pour
apporter un plus à votre projet&nbsp;;

* le cinquième onglet `Scénario` est sans doute le plus important pour
un(e) scénariste&nbsp;: c'est ici que s'écrit l'histoire, le scénario,
conformément aux règles du métier. Merci de consulter la doc wiki pour
plus d'information sur son utilisation détaillée&nbsp;;

* un petit outil supplémentaire est désormais disponible dans le menu
`Outils > Éléments de scénario` qui vous permet de régler plus finement
l'utilisation de l'éditeur de scénario qui se trouve dans le cinquième
onglet de l'application&nbsp;;

* le sixième onglet, `Storyboard`, permet de gérer le **découpage
technique** du scénario. Cet outil vous est offert en extra.
Normalement, le logiciel `tkScenarist` aurait dû s'arrêter à la
rédaction du scénario, mais pour les petits projets de film, je me suis
dit que ce serait bien pratique d'avoir aussi le storyboard à portée de
main&nbsp;;

* idem pour le septième onglet, `Ressources`, qui n'est là que pour
faciliter l'organisation des petits projets de film. Il va sans dire
qu'un projet de film plus ambitieux nécessitera sans aucun doute des
logiciels plus puissants (et moins gratuits, au passage)&nbsp;;

* l'outil d'exportation des données du projet vers le format PDF
imprimable autorise à présent la gestion de documents multiples,
séparés les uns des autres, avec des options à régler juste avant le
lancement de la procédure d'exportation&nbsp;;

* le logiciel `tkScenarist` est à présent entièrement traduit en
**français de France métropolitaine** (fr_FR).


## <a name="captures-d-ecran"/>Captures d'écran

![image](../../images/screenshots/fr/screenshot-001.png)
![image](../../images/screenshots/fr/screenshot-002.png)
![image](../../images/screenshots/fr/screenshot-003.png)
![image](../../images/screenshots/fr/screenshot-004.png)
![image](../../images/screenshots/fr/screenshot-005.png)
![image](../../images/screenshots/fr/screenshot-006.png)
![image](../../images/screenshots/fr/screenshot-007.png)
![image](../../images/screenshots/fr/screenshot-008.png)
![image](../../images/screenshots/fr/screenshot-009.png)
![image](../../images/screenshots/fr/screenshot-010.png)
![image](../../images/screenshots/fr/screenshot-011.png)
![image](../../images/screenshots/fr/screenshot-012.png)
![image](../../images/screenshots/fr/screenshot-013.png)

![image](../../images/screenshots/fr/screenshot-014.png)
![image](../../images/screenshots/fr/screenshot-015.png)
![image](../../images/screenshots/fr/screenshot-016.png)


## <a name="avancement-du-projet"/>Avancement du projet

    Development Status :: 5 - Production/Stable

Ce logiciel a été :

* Linux:
    * TESTÉ OK pour toutes les distributions standards ;
* MacOS:
    * PAS ENCORE TESTÉ ;
* MS-Windows:
    * TESTÉ seulement avec MS-Windows(tm) 8, mais semble fonctionner
    plutôt bien, pour le moment ;

Tout retour d'expérience dans le
**[bugtracker](https://github.com/tarball69/tkScenarist/issues)** du
projet est toujours le bienvenu.


## <a name="installation"/>Installation

Ce logiciel n'a *PAS* besoin d'être installé, de quelque manière que ce
soit.

Il vous suffit de le télécharger à la page
[Releases](https://github.com/tarball69/tkScenarist/releases) du projet
GitHub, de dézipper l'archive téléchargée et de l'utiliser
immédiatement.

Bien sûr, dans l'idéal, vous prendrez la précaution de copier le
dossier obtenu dans l'un de vos dossiers préférés &ndash; exemple
`apps` &ndash; sachant qu'un logiciel qui traîne dans le dossier des
téléchargements a toutes les chances de se faire supprimer
accidentellement.


## <a name="demarrage-rapide"/>Démarrage rapide

### <a name="important"/>Important

Ce logiciel ne peut fonctionner que si **Python3** (Python >= 3.3) et
**Tkinter** (Tcl/Tk >= 8.5) sont correctement installés sur votre
machine.

En revanche, il n'y a **pas d'autres dépendances** que ces deux
pré-requis.

Python3 est le langage de programmation utilisé par le logiciel
`tkScenarist` et Tkinter sa bibliothèque graphique, généralement
installée **par défaut** avec le langage Python3.

Si jamais vous obtenez un message d'erreur du type **ImportError** dans
la fenêtre noire (console) qui apparaît lors du lancement du logiciel,
c'est qu'il y a de fortes chances pour que vous essayiez de lancer le
programme avec **Python2** et non pas son grand frère **Python3**. Il
peut aussi arriver parfois que la bibliothèque Tkinter soit mal
installée, bien que ce soit rare.

Quoi qu'il en soit, n'hésitez pas à vous faire aider sur les forums
d'entraide appropriés (par exemple :
[AFPY.org](http://www.afpy.org/forums/forum_python)).

Notez que l'installation de Python3 à côté de Python2 ne pose
généralement aucun problème particulier.

Vous pouvez télécharger et installer Python3 à partir de cette
adresse&nbsp;:

<https://www.python.org/downloads/> (Ctrl+clic: nouvel onglet)

### <a name="note"/>Note

La plupart des distributions Linux populaires e.g. Ubuntu, Debian,
SuSE, etc. ont déjà une **pré-installation** de Python3/Tkinter.

Si vous êtes dans ce cas, **n'essayez pas** d'installer Python3/Tkinter
manuellement, cela pourrait mettre votre système en difficulté.

Dans un tel cas, il vous suffit de [télécharger une release](https://github.com/tarball69/tkScenarist/releases) de `tkScenarist`,
de la dézipper et de l'utiliser immédiatement.

### <a name="usagers-de-ms-windows"/>Usagers de MS-Windows&trade;

Une fois le dossier `tkScenarist-...` dézippé et copié en lieu sûr,
double-cliquez simplement sur le fichier `tkscenarist.py` qui se trouve
dedans pour lancer l'application.

Vous trouverez ce fichier dans le sous-dossier `tkScenarist` de
l'archive dézippée.

#### <a name="vous-ne-voulez-pas-la-console-noire"/>Vous ne voulez pas la console noire

Plusieurs usagers de MS-Windows&trade; ont fait remarquer qu'ils ont
une console MS-DOS noire qui apparaît au lancement du logiciel.

Cette fenêtre particulièrement disgracieuse peut même parfois être
carrément gênante.

Il s'agit cependant d'un comportement propre au langage Python sous
MS-Windows&trade; et **cela n'a rien d'anormal**.

Toutefois, si vous souhaitez vous débarrasser de cette console noire,
il vous suffit de changer l'extension du fichier `.py` en `.pyw` puis
de lancer à nouveau votre logiciel favori pour ne plus être embêté(e).

Dans le cas ici présent, cela revient à renommer le fichier
`tkscenarist.py` en `tkscenarist.pyw`, puis de relancer le programme
pour que cela fonctionne sans console.

### <a name="unixlinux"/>UNIX/Linux

Une fois le dossier `tkScenarist-...` dézippé et copié en lieu sûr,
cliquez simplement sur le fichier `tkscenarist.py` qui se trouve dedans
(si le sticky bit 'executable' autorise l'exécution du fichier tel
quel) pour lancer l'application.

Vous trouverez ce fichier dans le sous-dossier `tkScenarist` de
l'archive dézippée.

Si cela ne donne rien, ouvrez une console shell et tapez :

<pre class="codeblock">
    $ cd /emplacement/du/fichier # à remplacer, évidemment.
    $ python3 tkscenarist.py
</pre>

**Exemple concret&nbsp;:** en supposant que vous avez copié le dossier
`tkScenarist/` dans votre répertoire favori `~/apps/`, cela
donne&nbsp;:

<pre class="codeblock">
    $ cd ~/apps/tkScenarist
    $ python3 tkscenarist.py
</pre>

That's all, folks!

Amusez-vous bien !
